==> huaweicloudsdkprojectman-3.0.45-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/batch_delete_iterations_v4_request.py <==
# coding: utf-8

import pprint
import re

import six





class BatchDeleteIterationsV4Request:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'body': 'BatchDeleteIterationsV4RequestBody'
    }

    attribute_map = {
        'project_id': 'project_id',
        'body': 'body'
    }

    def __init__(self, project_id=None, body=None):
        """BatchDeleteIterationsV4Request - a model defined in huaweicloud sdk"""
        
        

        self._project_id = None
        self._body = None
        self.discriminator = None

        self.project_id = project_id
        if body is not None:
            self.body = body

    @property
    def project_id(self):
        """Gets the project_id of this BatchDeleteIterationsV4Request.

        项目id

        :return: The project_id of this BatchDeleteIterationsV4Request.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this BatchDeleteIterationsV4Request.

        项目id

        :param project_id: The project_id of this BatchDeleteIterationsV4Request.
        :type: str
        """
        self._project_id = project_id

    @property
    def body(self):
        """Gets the body of this BatchDeleteIterationsV4Request.


        :return: The body of this BatchDeleteIterationsV4Request.
        :rtype: BatchDeleteIterationsV4RequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this BatchDeleteIterationsV4Request.


        :param body: The body of this BatchDeleteIterationsV4Request.
        :type: BatchDeleteIterationsV4RequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchDeleteIterationsV4Request):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkprojectman-3.0.51-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/batch_delete_iterations_v4_request.py <==
# coding: utf-8

import re
import six





class BatchDeleteIterationsV4Request:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'body': 'BatchDeleteIterationsV4RequestBody'
    }

    attribute_map = {
        'project_id': 'project_id',
        'body': 'body'
    }

    def __init__(self, project_id=None, body=None):
        """BatchDeleteIterationsV4Request - a model defined in huaweicloud sdk"""
        
        

        self._project_id = None
        self._body = None
        self.discriminator = None

        self.project_id = project_id
        if body is not None:
            self.body = body

    @property
    def project_id(self):
        """Gets the project_id of this BatchDeleteIterationsV4Request.

        项目id

        :return: The project_id of this BatchDeleteIterationsV4Request.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this BatchDeleteIterationsV4Request.

        项目id

        :param project_id: The project_id of this BatchDeleteIterationsV4Request.
        :type: str
        """
        self._project_id = project_id

    @property
    def body(self):
        """Gets the body of this BatchDeleteIterationsV4Request.


        :return: The body of this BatchDeleteIterationsV4Request.
        :rtype: BatchDeleteIterationsV4RequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this BatchDeleteIterationsV4Request.


        :param body: The body of this BatchDeleteIterationsV4Request.
        :type: BatchDeleteIterationsV4RequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchDeleteIterationsV4Request):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
